<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=fon
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'aide_non_disponible' => 'Akpaxwé élɔ sín àlɔgɔ kó sɔgbè ɖò àtɛ ɔ jí ɖò gbè é lɔ mɛ a ',
	'avis_acces_interdit' => 'Alì ɖè a',
	'avis_article_modifie' => 'Vlɛ, @nom_auteur_modif@ nyowlántɔ é wàzɔ ɖò wêmá é lɔ jí ɔ @date_diff@ ɖò cɛjúmɛ ɔ .',
	'avis_aucun_resultat' => 'Gbètà ɖébú tíìn a',
	'avis_chemin_invalide_1' => 'Alì é mi sɔ ɔ ',
	'avis_chemin_invalide_2' => 'E pkézín a. mi lɛkɔ yì wêmà ɖê wáyí jí bó vɔ kpɔn xógbè lɛ .',
	'avis_connexion_echec_1' => 'Mi síwú cálɔ dó Mɔxwìtíxwìtítàtɔ MySql tɔn a.', # MODIF
	'avis_connexion_echec_2' => 'Mi lɛkɔ yì wêmà ɖê wáyí jí, bó vɔ kpɔn xógbè mi ná lɛ .',
	'avis_connexion_echec_3' => 'Do atɛ gege ji ɔ, mi do na byɔ cavi mi tɔn é mi na byɔ mysql mɛ ɔ, co e na wazɔ. Nu mi sin wu tɛ dowu ɔ, mi kpɔ ɖɔ miɖè afɔ e nɛ a ji.', # MODIF
	'avis_connexion_ldap_echec_1' => 'Cacadó do LDAP ɔ gblé',
	'avis_connexion_ldap_echec_2' => 'Mi bo lɛ kɔ  yi wekpa gudo tɔ̂n ji bo kpɔn ɖɔ xogbè mi tɔn mi sɛdo lɛ ',
	'avis_connexion_ldap_echec_3' => 'Mi ma zan LDAP bo do ylɔ zizantɔ lɛ do zɛnzɛn o',
	'avis_deplacement_rubrique' => 'vlɛ! @contient_breves@ brève@scb@ ɖé lɛ̂ do akpa é lɔ mɛ : n sɛ sinɔ, mi tɛnkpɔn bo sɔ xlɛ tɔn do fi.',
	'avis_erreur_connexion_mysql' => 'afɔkiklɛn do cacado mysql tɔn mɛ ',
	'avis_espace_interdit' => 'acɛku Yé ko  ze supipu do fi nɛ',
	'avis_lecture_noms_bases_1' => 'nyikɔ kpodo gbɛtakɛnxokplé lɛ̂  ye do Titomɛ ɔ mɛ a  ',
	'avis_lecture_noms_bases_2' => 'Kabi gbɛtakɛnxokplé ɖé a , kabi  nuwé nɔ zɔn bɔ mi nɔ to gbɛtakɛnxokplé lɛ sin acɛ ku.sɔ ɖo ayi ni ja wu ɔ ( mɔ wɛ e ɖé lo xwétɔ gege gɔn)',
	'avis_lecture_noms_bases_3' => 'ɖo sisɔ akpa dévo tɔn mɛ ɔ, Yé siwu zan gbɛtakɛnxokplé ɖé sɔ nyikɔ mi tɔn ',
	'avis_non_acces_page' => 'Mi siwu yi wekpa é lɔ ji à ',
	'avis_operation_echec' => 'azɔ̂ gbé',
	'avis_suppression_base' => 'vlɛ ! nu mi sunsun gbètakɛn lɛ̂ ɔ é vɔ bi sésé',

	// B
	'bouton_acces_ldap' => 'Mi zé gɔna LDAP',
	'bouton_ajouter' => 'Mi gɔna ',
	'bouton_demande_publication' => 'Mi kàn ɖiɖétɔn wékpa é lɔ tɔn byɔ',
	'bouton_effacer_tout' => 'Mi sùnsun bi',
	'bouton_envoyer_message' => 'wɛn gudogudotɔn : sɛdo',
	'bouton_modifier' => 'ɖyɔ',
	'bouton_radio_afficher' => 'mi xlɛ',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'ɖo xlɛ ɖo ɖiɖè nyɔwlantɔ̂é ɖo kan ji lɛ',
	'bouton_radio_envoi_annonces_adresse' => 'Mi sɛ xojla do',
	'bouton_radio_envoi_liste_nouveautes' => 'mi  kplé xogbè yɔyɔ lɛ̂ do ',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'mi ma ɖo xlɛ ɖo ɖiɖè nyɔwlantɔ  tɔn mɛ o ',
	'bouton_radio_non_envoi_annonces_editoriales' => 'mi ma sɛ gbètàxojla do',
	'bouton_redirection' => 'mi lɛ vɔ jlɛ',
	'bouton_relancer_installation' => 'Mi lɛ vɔ  afɔɖotè ɔ blo',
	'bouton_suivant' => 'E jɛ gudo  ɔ',
	'bouton_tenter_recuperation' => 'mi nà tɛnkpɔn bo bloɖo',
	'bouton_test_proxy' => 'mi  tɛn proxy kpɔn ',
	'bouton_vider_cache' => 'bɛ simɛ',

	// C
	'cache_modifiable_webmestre' => 'mɛ lò mɔɔjí ɔ hɛn ɔ é ná vɔ ɖiɖèmɛ bló',
	'calendrier_synchro' => 'Nú jó ná zán gbèta, mi siwú xò bí kplé ',

	// D
	'date_mot_heures' => 'ganmɛ lɛ',

	// E
	'email' => 'e-mailu',
	'email_2' => 'e-mailu',
	'entree_adresse_annuaire' => 'gési wěma ',
	'entree_adresse_email' => 'e-mailu mī tɔn',
	'entree_base_donnee_1' => 'gési gbèta bɛɖókpɔ',
	'entree_base_donnee_2' => 'hwéɖé lɛ tin ɔ  gési é lɔ nɔ jɛ dó gblògblòjí mī wú',
	'entree_biographie' => 'wl nú ɖó gbɛ zan mɛ tɔn wu ɖó kléwun mɛ',
	'entree_chemin_acces' => 'hɔntogbó',
	'entree_cle_pgp' => 'cávì PGP',
	'entree_contenu_rubrique' => 'mī ɖɔ xó é ɖò akpaxwé ɔ mɛ ɔ ɖó kléwunmɛ',
	'entree_identifiants_connexion' => 'mī zé mì xlɛ',
	'entree_informations_connexion_ldap' => 'mī zé mì xlɛ',
	'entree_infos_perso' => 'mɛ cé ká ɖyè ',
	'entree_interieur_rubrique' => 'ɖò akpaxwé ɔ mɛ',
	'entree_liens_sites' => 'cacadó gblògblòjí ɔ tɔn',
	'entree_login' => 'nyìkɔ mī tɔn ',
	'entree_login_connexion_1' => 'nyìkɔ mī tɔn ',
	'entree_login_connexion_2' => 'nyìkɔ mī tɔn ',
	'entree_mot_passe' => 'cávì mī tɔn ',
	'entree_mot_passe_1' => 'cávì mī tɔn ',
	'entree_mot_passe_2' => 'cávì mī tɔn ',
	'entree_nom_fichier' => 'mī sɛ nyìkɔ gbètà tɔn ɔ sɛɖó ',
	'entree_nom_pseudo' => 'mī sɛ sùnyìkɔ tɔn sɛɖó',
	'entree_nom_pseudo_1' => ' nyìkɔ mi tɔn àlo sùnyìkɔ tɔn ',
	'entree_nom_site' => 'gblògblòjí tɔn sin nyìkɔ',
	'entree_nouveau_passe' => 'cávì ɖévó',
	'entree_passe_ldap' => 'cávì ',
	'entree_port_annuaire' => 'numɛlo wěma tɔn',
	'entree_signature' => 'àlɔ ɖó wěmá mɛ',
	'entree_titre_obligatoire' => 'xótá dandan',
	'entree_url' => 'gési gblogboji ton',

	// I
	'ical_info1' => 'nú mi ná ɖó àcéjí kpóɖó gblogblojí é lɔ mi kpɔn wàlɔ tòbútòbú é lò wěkpá jí ɔ .',
	'ical_info2' => 'Nú mi lɛ lò xógbè xwítíxwítí bà wɛ ɔ mi síkú yí sùpípú sín xóxòkplémɛ.', # MODIF
	'ical_info_calendrier' => 'Yè sɛ kàlànɖlyé wè ɖó mí. ɖòkpó nyí gblogblojí ɔ sín tìtòmɛ tɔn bó nɔ xlɛ wě ɖé yè wlàn lɛ bí. Wègɔ ɔ é nyí xógbèɖòtàjì kpó wɛn mì tɔn vívɛná lɛ kpó jí : mi ɖó càvì mi tɔn, bɔ mi lɛ hɛn ɔ mi ná lɛ  nɔ ɖyɔ ɛ kpódó gbètákɛn. .',
	'ical_methode_http' => 'ɖìɖɔn ',
	'ical_methode_webcal' => 'mìmá', # MODIF
	'ical_texte_js' => 'ɖìdèmɛ javasùclipù tɔn  ná síwú nɔ mi ná xlɛ wěkpá gùdógùdó tɔn lɛ ɖò gblogblojí ɖébújí..',
	'ical_texte_prive' => 'kàlànɖlyé é lɔ é nyí miɖɛsú tɔn ɔn, nɔ ná xógbè ɖó xógbèɖòtàjìzɔ gblogblojí ɔ tɔ wú',
	'ical_texte_public' => 'kàlànɖlyé ná ná bɔ nùkún mi tɔn ná nɔ gblogblojí ɔ sín àzɔnùkùnɖéjí ɔ jí.',
	'ical_texte_rss' => 'Mí hɛn ɔ mi siwú má xógbè yɔyɔ é lò gblogblo ɔ jí é, mi sìkú lɛ zán xìxàtɔ ɖébú bóɖó xà  XML/RSS/. ',
	'ical_titre_js' => 'Javasucriptu',
	'ical_titre_mailing' => 'Mailing-list',
	'ical_titre_rss' => 'Xótá « backend »',
	'icone_activer_cookie' => 'Zin kwín é jɛ ɖó',
	'icone_afficher_auteurs' => 'Zé nyɔwlántɔ lɛ xlɛ',
	'icone_afficher_visiteurs' => 'ɖè jonɔ lɛ xlɛ',
	'icone_arret_discussion' => 'é má sɔ kɛnudo xómɛ o',
	'icone_calendrier' => 'kàlánɖlyé',
	'icone_creer_auteur' => 'Mi ɖè gbètakɛn yɔyɔ dévó tɔn ',
	'icone_creer_mot_cle' => 'Mi zé nyɔwlántɔ yɔyɔ dévó tɔn bó cáɖó wěkpá',
	'icone_creer_rubrique_2' => 'Mi ɖè àkpáxwé dévó tɔn',
	'icone_modifier_article' => 'mi vɔ ɖyɔ wékpá',
	'icone_modifier_rubrique' => 'mi vɔ ɖyɔ àkpáxwé ɔ',
	'icone_retour' => 'lɛkɔ',
	'icone_retour_article' => 'lɛkɔ yì wěkpá ɔ jí',
	'icone_supprimer_cookie' => 'gbìɖí kwín jɛ ɖé wú lɛ',
	'icone_supprimer_rubrique' => 'gbìɖí àkpáxwé é lɔ',
	'icone_supprimer_signature' => 'gbìɖí àlɔɖówěmámɛ é lɔ',
	'icone_valider_signature' => 'sɔ kɛn nú àlɔɖówěmámɛ é lɔ',
	'image_administrer_rubrique' => 'Mi síw tò àkpáxwé é lɔ',
	'info_1_article' => 'wěkpá ɖòkpó',
	'info_activer_cookie' => 'Mi sí wlán xógbè é sɔgbèbɔ mi ná dó jɛ àgun dévómɛ.',
	'info_administrateur' => ' tìtòtɔ ',
	'info_administrateur_1' => 'tìtòtɔ',
	'info_administrateur_2' => 'gblogblojí  yè z kpó yɛyì',
	'info_administrateur_site_01' => 'nú mi nyí tìtòtɔ  gblogblojí tɔn ɔ mi kɛnklyɛn bó',
	'info_administrateur_site_02' => 'mi zín fí',
	'info_administrateurs' => 'tìtòtɔ lɛ',
	'info_administrer_rubrique' => 'mi hɛn ɔ mi ná to àkpáxwé é lɔ ',
	'info_adresse' => 'nɔtɛn',
	'info_adresse_url' => 'nɔtɛn gblogblojí ɔ tɔn ',
	'info_aide_en_ligne' => 'àlɔdó sùpípù tɔn',
	'info_ajout_image' => 'àlɔdó sùpípù tɔn.',
	'info_ajouter_rubrique' => 'mi gɔ xókwín dókpó  ná:',
	'info_annonce_nouveautes' => 'xójíjlá yɔyɔ lɛ',
	'info_article' => 'wěkpá',
	'info_article_2' => 'wěkpá',
	'info_article_a_paraitre' => 'wěkpá yé ɖó àzán ná',
	'info_articles_02' => ' wěmâ',
	'info_articles_2' => 'wěmâ',
	'info_articles_auteur' => 'nyɔwlántɔ é lɔ sín wěmà',
	'info_articles_trouves' => 'wěmà yè mɔ é',
	'info_attente_validation' => 'mi ɖòtè bò ná sɔ kɛn nú wěmà lɛ ',
	'info_aujourdhui' => 'égbé:',
	'info_auteurs' => 'Nyɔwlántɔ lɛ̂',
	'info_auteurs_par_tri' => 'Nyɔwlántɔ (lɛ̂)',
	'info_auteurs_trouves' => 'Nyɔwlántɔ lɛ̂ ɖê mi mɔ ɔ',
	'info_authentification_externe' => 'Acɛ yíyí',
	'info_avertissement' => 'Mi có mi ɖé',
	'info_base_installee' => 'Tìtòmɛ gbètákɛnxòkplé mi tɔn ô sɔgbè.',
	'info_chapeau' => 'gbàkún',
	'info_chapeau_2' => 'gbàkún:',
	'info_chemin_acces_1' => 'àlì yé ná dó byɔ mɛ ɔ',
	'info_chemin_acces_2' => 'àlì yé ná dó byɔ mɛ ɔ.',
	'info_chemin_acces_annuaire' => 'àlì yé ná dó byɔ mɛ ɔ',
	'info_choix_base' => 'Nɔtɛn àtɔn gɔ̂:',
	'info_classement_1' => ' @listù@',
	'info_classement_2' => '@listù@',
	'info_code_acces' => 'Mi mà wɔn gbètɛn mi tɔn lɛ ó!',
	'info_config_suivi_explication' => 'Mi hɛn ɔ mi ná á nyíkɔ ɖò fi',
	'info_confirmer_passe' => 'Mi vɔ gbètákɛn mi tɔn sɛɖó:',
	'info_connexion_base' => 'Nɔtɛn wè gɔ̂',
	'info_connexion_ldap_ok' => 'cácáɖó ɔ fɛwú, mi hɛn me ná yí Nɔtɛn wè gɔ̂ jí.', # MODIF
	'info_connexion_mysql' => 'Nɔtɛn ŋkɔnŋkɔn tɔn ɔ ',
	'info_connexion_ok' => 'cácáɖó ɔ fɛwú.',
	'info_contact' => 'Nɔtɛn',
	'info_contenu_articles' => 'wékpá lɛ ',
	'info_creation_paragraphe' => 'nú mi ná xò wékpá kplé ɔ mi nɔ lɔn ɖòkpó ɖòkpó', # MODIF
	'info_creation_rubrique' => 'cóhwɛ mi nɛ nú wlán jí ɔ, mi ɖó ná ɖè àkpáxwé tɔn hwɛ',
	'info_creation_tables' => 'Nɔtɛn ɛnɛ gɔ̂',
	'info_creer_base' => 'ɖè gbetá xokplé dévó',
	'info_dans_rubrique' => 'ɖò àkpáxwé  ɔ mɛ :',
	'info_date_publication_anterieure' => 'àzán gùdó tɔn :',
	'info_date_referencement' => 'àzán gùdó tɔn :',
	'info_derniere_etape' => 'Nɔtɛn gùdó tɔn ɔ!',
	'info_descriptif' => 'ɖìɖèmɛ :',
	'info_discussion_cours' => 'xó kpó ɖò yìyì wɛ',
	'info_ecrire_article' => 'có hwɛ mi nɛ nú wlán jí ɔ, mi ɖó ná ɖè àkpáxwé tɔn hwɛ',
	'info_email_envoi' => 'e-mailù',
	'info_email_envoi_txt' => 'mi dó gesi bó ná sɛ e-mailù lɛ ɖó:',
	'info_email_webmestre' => 'tìtòtì sín e-mailù', # MODIF
	'info_envoi_email_automatique' => 'sɛ e-mailù ɖó àzɔn ɖókpó',
	'info_envoyer_maintenant' => 'sɛɖó ɖìn',
	'info_etape_suivante' => 'mi yí tɛnɔtɛ é bɔɖéwú ɔ jí',
	'info_etape_suivante_1' => 'mi yí tɛnɔtɛ é bɔɖéwú ɔ jí.',
	'info_etape_suivante_2' => 'mi yí tɛnɔtɛ é bɔɖéwú ɔ jí.',
	'info_exportation_base' => 'bíbɛ xóxókplé sɔ yì',
	'info_facilite_suivi_activite' => 'bíbɛ xóxókplé sɔ yì',
	'info_fichiers_authent' => 'xó xókplé ',
	'info_forums_abo_invites' => 'jōnɔ lɛ ní ná nyíkɔ.',
	'info_gauche_admin_tech' => 'wémà é lɔ Tìtòtɔ lɛ kɛɖɛ wɛ síwú dàlɔmɛ', # MODIF
	'info_gauche_admin_vider' => 'wémà é lɔ Tìtòtɔ lɛ kɛɖɛ wɛ síwú dàlɔmɛ', # MODIF
	'info_gauche_auteurs' => 'Dò fyɔ, mí ná mɔ Tìtòtɔ gblogblojí ɔ tɔn lɛ .',
	'info_gauche_auteurs_exterieurs' => 'Dò fyɔ, mí ná mɔ Tìtòtɔ gblogblojí ɔ tɔn lɛ .', # MODIF
	'info_gauche_messagerie' => 'Winwlántɛnmɛ nɔ ná bɔ nyɔwlántɔ síwú nɔ ɖɔxó ɖó kpɔ.',
	'info_gauche_statistiques_referers' => 'wémà é lɔ Tìtòtɔ lɛ kɛɖɛ wɛ síwú dàlɔmɛ',
	'info_gauche_visiteurs_enregistres' => 'jōnɔ bíbà sín akɔnŋtà',
	'info_generation_miniatures_images' => 'Nú títɛ lɛ ɖê yē zé bló gbètákɛn ná',
	'info_hebergeur_desactiver_envoi_email' => 'e-mailù càcà.',
	'info_hier' => 'sɔ tó fí:',
	'info_identification_publique' => 'Nyíkɔ mi tɔn tòbítùn...',
	'info_image_process' => 'Mi cyán wàlɔ ɖàgbè lɛ.',
	'info_image_process2' => 'Mi cyán wàlɔ ɖàgbè lɛ', # MODIF
	'info_informations_personnelles' => 'Tɛnnɔtɛn àtɔ̂n gɔ̂',
	'info_inscription_automatique' => 'nyíkɔníná nyɔwlántɔ lɛ tɔn',
	'info_jeu_caractere' => 'Wékwín àjì gblogbloji',
	'info_jours' => 'Azán lɛ',
	'info_laisser_champs_vides' => 'Mi jò tɛnmɛ dó',
	'info_langues' => 'Gbè gblogblojí ɔ tɔn',
	'info_ldap_ok' => 'jíjlɛmɛ.',
	'info_lien_hypertexte' => 'càcàdó :',
	'info_liste_redacteurs_connectes' => 'nyɔwlátɔ é ɖò kânú é',
	'info_login_existant' => 'nyíkɔ é lɔ kòɖè.',
	'info_login_trop_court' => 'nyíkɔ̂ hwè.',
	'info_maximum' => 'Bísésé:',
	'info_meme_rubrique' => 'Akpáxwé ɖókpó ɔ',
	'info_message_en_redaction' => 'yè kpò ɖò wɛn wlàn wɛ',
	'info_message_technique' => 'wɛn xwítxwítí :',
	'info_messagerie_interne' => 'Winwlántɛnmɛ',
	'info_mise_a_niveau_base' => 'Mi lɛ vɔ bló SQL',
	'info_mise_a_niveau_base_2' => 'Mi lɛ vɔ bló',
	'info_modifier_rubrique' => 'ɖyɔ Akpáxwé ɔ:',
	'info_modifier_titre' => 'ɖyɔ Akpáxwé ɔ: @xota@',
	'info_mon_site_spip' => 'gblogblojí supipu tɔn cè',
	'info_moyenne' => 'Tɛntímɛ:',
	'info_multi_cet_article' => 'Gbè wékpá é lɔ tɔn :',
	'info_multi_langues_choisies' => 'Mi kɛnklɛn bó sɔ gbè é jló myɔ',
	'info_multi_secteurs' => 'Akpáxwé é lò ɖòkɔ lɛ kɛɖɛ a ?',
	'info_nom' => 'E wó',
	'info_nom_destinataire' => 'nyíkɔ mɛ ná yí ɔ tɔn',
	'info_nom_site' => 'gblogblojí mi tɔn sín nyíkɔ',
	'info_nombre_articles' => '@nb_articles@ wékpá,',
	'info_nombre_rubriques' => '@nb_rubriques@ àkpáxwé lɛ,',
	'info_nombre_sites' => '@nb_sites@ gblogblojí ,',
	'info_non_deplacer' => 'yè mà sɛ wó...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'Supipu hɛn é ná sɛ wɛn gùdótɔn lɛ ɖó.',
	'info_non_envoi_liste_nouveautes' => 'Mi sɛ wɛn yɔyɔ lɛ dó ò',
	'info_non_modifiable' => 'Yé sín ɖyɔ á',
	'info_non_suppression_mot_cle' => 'ŋ jó ná súnsún gbètɛn ɔ á.',
	'info_notes' => 'wê',
	'info_nouvel_article' => 'wékpá yɔyɔ',
	'info_nouvelle_traduction' => 'Tínmɛ ɖévó:',
	'info_numero_article' => 'Wékpá nùméló:',
	'info_obligatoire_02' => '[dódó]', # MODIF
	'info_option_accepter_visiteurs' => 'Mi yí gbè nú jònɔ é ná nyíkɔ lɛ ',
	'info_option_ne_pas_accepter_visiteurs' => 'Mi gbɛ nyíkɔ jónɔ é lɔ tɔn ',
	'info_options_avancees' => 'wàlɔ é ɖrɛn àfɔ ',
	'info_ou' => 'fítɛ...',
	'info_page_interdite' => 'àlì sú',
	'info_par_nombre_article' => '(ɖìɖèmɛ wékpá )',
	'info_passe_trop_court' => 'gbètákɛn ɔ hwè.',
	'info_passes_identiques' => 'gbètákɛn wè lɛ sɔgbè á.',
	'info_plus_cinq_car' => 'E hú wékwín àtɔ̂n',
	'info_plus_cinq_car_2' => '(E hú wékwín àtɔ̂n)',
	'info_plus_trois_car' => '(E hú wékwín àtɔn)',
	'info_popularite' => 'Tòbítù: @popularite@ ; Jōnɔ: @visites@',
	'info_post_scriptum' => 'Gbè ní ná',
	'info_post_scriptum_2' => 'Gbè ní ná :',
	'info_pour' => 'gbɔn',
	'info_preview_texte' => 'wàlɔ kpíkpɔn tɔn sɔ ɖò gbɛ á', # MODIF
	'info_procedez_par_etape' => 'wàlɔ ɖòkpó ɖòkpó',
	'info_procedure_maj_version' => 'wàlɔ ɖòkpó ɖòkpó.',
	'info_ps' => 'P.S',
	'info_publies' => 'yè sɔ kɛn ná',
	'info_question_accepter_visiteurs' => 'Nɛ nyí ɖɔ tìtòmɛ mi tɔn bà ɖɔ é mi ná wlí jōnɔ lɛ hɛn ɔ :',
	'info_question_inscription_nouveaux_redacteurs' => 'Mi yí gbè nú nyɔwántɔ yɔyɔ lɛ à.', # MODIF
	'info_racine_site' => 'gblogblojí ɔ sín dɔ',
	'info_recharger_page' => 'mi lɛ vɔ jlɔ wémà é lɔ ɖò cɛjú ywɛywɛmɛ.',
	'info_recherche_auteur_zero' => 'xókwìn lɛ « @cherche_auteur@ ».',
	'info_recommencer' => 'Mi lɛ νɔ bɛ.',
	'info_redacteur_1' => 'Nyɔwlántɔ ',
	'info_redacteur_2' => 'Mɛ ɖó àcɛ bó byɔ mɛ(<i>recommandé</i>)',
	'info_redacteurs' => 'Nyɔwlántɔ lɛ',
	'info_redaction_en_cours' => 'Yé kpó ɖó wíwlán wɛ',
	'info_redirection' => 'Mi lɛ vɔ jlɛ',
	'info_refuses' => 'Wékpá mi tɔn yè gbɛ ɔ',
	'info_reglage_ldap' => 'wàlɔ  : jlɔjlɔ tɛnme',
	'info_renvoi_article' => 'wàlɔ.Wékpá sɛ yí ê:',
	'info_reserve_admin' => 'Tìtòtɔ lɛ kɛɖɛ jɛn sín ɖyɔ nɔtɛn ɔ.',
	'info_restreindre_rubrique' => 'Mi ɖè tìtò àkpáxwé ɔ tɔn kpò :',
	'info_resultat_recherche' => 'Xógbè yè mɔ lɛ :',
	'info_rubriques' => 'àkpáxwé',
	'info_rubriques_02' => 'àkpáxwé lɛ',
	'info_rubriques_trouvees' => 'àkpáxwé lɛ ɖê yè mɔ̂',
	'info_sans_titre' => 'Xótá ɖè á',
	'info_selection_chemin_acces' => 'Mi cyán  àlì é byoɔ wégbó ɔ mɛ ɔ :',
	'info_signatures' => 'Alɔɖówěmámɛ lɛ',
	'info_site' => 'gblogblojí',
	'info_site_2' => 'gblogblojí:',
	'info_site_min' => 'gblogblojí',
	'info_site_reference_2' => 'Gblogblojí yé ɖèkúnú ná ',
	'info_site_web' => 'Gblogblojí :', # MODIF
	'info_sites' => 'Gblogblojí',
	'info_sites_lies_mot' => 'Gblogblojí ɖê cáɖó gbètákɛn ɔ nú ɔ ',
	'info_sites_proxy' => 'Mi zán  proxy',
	'info_sites_trouves' => 'gblogblojí ɖê mɔ lɛ',
	'info_sous_titre' => 'xótákpɛví:',
	'info_statut_administrateur' => 'Tìtòtɔ',
	'info_statut_auteur' => 'Nyɔwlán sín tìtòmɛ:', # MODIF
	'info_statut_redacteur' => 'Nyɔwlántɔ',
	'info_statut_utilisateurs_1' => 'nɔtè kpòhùn',
	'info_statut_utilisateurs_2' => 'mi cyán nɔtè mɛ̂ ɖò LDAP sín wěmámɛ é nú yé sɔ yéɖé xlɛ ɔ núkɔnnúkɔntɔ̂n..',
	'info_suivi_activite' => 'mi ɖò wěgbó ɔ  wàlɔ kpɔn wɛ',
	'info_surtitre' => 'xótá ɖàxó :',
	'info_taille_maximale_vignette' => 'jlɛjlɛmɛ ɖìdè lɛ tɔn :',
	'info_terminer_installation' => 'mi hɛn ɔ mi síwú fó tɛnmɛ bíbló.',
	'info_texte' => 'wě',
	'info_texte_explicatif' => 'wě tìnmɛ',
	'info_texte_long' => 'é yá ɔ mi ná sɔ kɛn ní.)',
	'info_texte_message' => 'wě wɛn mi tɔn :', # MODIF
	'info_texte_message_02' => 'wě wɛn mi tɔn',
	'info_titre' => 'xótá :',
	'info_total' => 'Bísésé:',
	'info_tous_articles_en_redaction' => 'Wékpá lɛ kpó  nyí wlánwlántɔ',
	'info_tous_articles_presents' => 'Wékpá lɛ yè zéɖò àkpáxwé é lɔ̂',
	'info_tous_les' => 'Yé bî:',
	'info_tout_site' => 'Gblògblòjí ɔ bí',
	'info_tout_site2' => 'Yé tìnmɛ wěkpâ ɖó gbè ɖé mɛ á.',
	'info_tout_site3' => 'Yé tìnmɛ wěkpâ ɖó gbè ɖé mɛ á',
	'info_tout_site4' => 'Yé tìnmɛ wěkpâ ɖó gbè ɖé mɛ .',
	'info_tout_site5' => 'wěkpâ fɛwú.',
	'info_tout_site6' => 'wěkpâ fɛwú jɛn yé sɔ xlɛ
 :',
	'info_travail_colaboratif' => 'mi wàzɔ ɖó kpɔ ɖò wékpá lɛ jí',
	'info_un_article' => 'wěkpâ,',
	'info_un_site' => 'Gblògblòjí ,',
	'info_une_rubrique' => 'àkpáxwé,',
	'info_une_rubrique_02' => 'àkpáxwé',
	'info_url' => 'URL :',
	'info_urlref' => 'àlɔwlí :',
	'info_utilisation_spip' => 'mi síwú jɛ tìtò ɖiɖèxlɛ tɔn zán jí...',
	'info_visites_par_mois' => 'ɖìdèxlɛ sùn ɖòkpó mɛ tɔn:',
	'info_visiteur_1' => 'jónɔ ',
	'info_visiteur_2' => 'Gblògblòjí',
	'info_visiteurs' => 'jónɔ lɛ',
	'info_visiteurs_02' => 'jónɔ Gblògblòjí tɔn',
	'install_select_langue' => 'bɔ mi jɛ tɛnmɛ blóɖó jí.',
	'intem_redacteur' => 'nyɔwlántɔ',
	'item_accepter_inscriptions' => 'mi yígbè nú nyíkɔnáná lɛ',
	'item_activer_messages_avertissement' => 'mi jɛ sɛn dó jí',
	'item_administrateur_2' => 'Tìtótɔ ',
	'item_afficher_calendrier' => 'Mi ɖè kalánɖlyé lɛ xlɛ',
	'item_choix_administrateurs' => 'Tìtótɔ lɛ',
	'item_choix_generation_miniature' => 'Mi tò ɖéxlɛ lɛ cíkícíkí.',
	'item_choix_non_generation_miniature' => 'Mi mà tò ɖéxlɛ lɛ cíkícíkí.',
	'item_choix_redacteurs' => 'nyɔwlántɔ lɛ',
	'item_choix_visiteurs' => 'jónɔ lɛ',
	'item_creer_fichiers_authent' => 'Gbètáxó lɛ.htpasswd',
	'item_login' => ' nyíkɔ ',
	'item_mots_cles_association_articles' => 'Wékpá lɛ',
	'item_mots_cles_association_rubriques' => 'àkpáxwé ɔ ',
	'item_mots_cles_association_sites' => 'mímàmɛ.',
	'item_non' => 'éwó',
	'item_non_accepter_inscriptions' => 'yí gbè nú nyíkɔ lɛ ',
	'item_non_activer_messages_avertissement' => 'mi jɛ sɛn dó jí',
	'item_non_afficher_calendrier' => 'Mi ɖè kalánɖlyé lɛ xlɛ wo',
	'item_non_creer_fichiers_authent' => 'mi má sɔ bló xótá ô',
	'item_non_publier_articles' => 'mi má sɔ xlɛ wékpá lɛ có àzán lɛ ní wâ.',
	'item_nouvel_auteur' => 'nyɔwlántɔ yɔyɔ',
	'item_nouvelle_rubrique' => 'àkpáxwé yɔyɔ',
	'item_oui' => 'ɛ̂',
	'item_publier_articles' => 'mi zé wékpá é lɔ lɛ sɔ, é ná bò tɛ nyí àzanɖébú.',
	'item_reponse_article' => 'yígbè nú wékpá',
	'item_visiteur' => 'jònɔ',

	// J
	'jour_non_connu_nc' => 'n.c.',

	// L
	'lien_ajouter_auteur' => 'mi zé nyɔwlátɔ  zé gɔn ná',
	'lien_email' => 'e-mailu',
	'lien_nom_site' => 'nyíkɔ gblogblojí ɔ tɔn  :',
	'lien_retirer_auteur' => 'mi ɖè nyɔwlátɔ sín ',
	'lien_site' => 'gblogblojí',
	'lien_tout_deplier' => 'mi vlɔn bí',
	'lien_tout_replier' => 'mi blán bí',
	'lien_trier_nom' => 'mi cyán nyìkɔmɛ',
	'lien_trier_nombre_articles' => 'mi cyán wékpámɛ',
	'lien_trier_statut' => 'mi cyán tènìnɔmɛ',
	'lien_voir_en_ligne' => 'mi kpɔn ɖò kànnú:',
	'logo_article' => 'sɔsí wékpá ɔ tɔn', # MODIF
	'logo_auteur' => 'sɔsí nyɔwlántɔ tɔn', # MODIF
	'logo_rubrique' => 'sɔsí àkpáxwé ɔ tɔn', # MODIF
	'logo_site' => 'sɔsí gblogbljí  ɔ tɔn', # MODIF
	'logo_standard_rubrique' => 'sɔsí àkpáxwé ɔ tɔn', # MODIF
	'logo_survol' => 'sɔsí zìwlɔn tɔn ', # MODIF

	// M
	'menu_aide_installation_choix_base' => 'mi cyán xógbè lɛ ',
	'module_fichier_langue' => 'gbè lɛ sín wěmà ',
	'module_raccourci' => 'xásádómɛ',
	'module_texte_affiche' => 'wěmà  yè ɖéxlɛ',
	'module_texte_explicatif' => 'mi zé xásádómɛ ɖé mɛ, yé ná tìnmɛ bléwún ɖò gbɛ lɛ mɛ .',
	'module_texte_traduction' => 'gbè  sín wěmà  « @module@ » ',
	'mois_non_connu' => ' yé tùn á ',

	// O
	'onglet_repartition_actuelle' => 'Hwé élɔ nú',

	// R
	'required' => '[dódó]', # MODIF

	// S
	'statut_admin_restreint' => '(tìto kléwún)', # MODIF

	// T
	'taille_cache_infinie' => 'tìto kléwún.',
	'taille_cache_maxi' => 'tìto kléwún',
	'taille_cache_octets' => 'tìto kléwún de @octets@.', # MODIF
	'taille_cache_vide' => 'gbàví ɔ jɛ vɔ.',
	'taille_repertoire_cache' => 'gbàví ɔ jɛ vɔ',
	'text_article_propose_publication' => 'mi kɛnklɛ̂n bó ná lìnlìn mi tɔn ɖé wúɖò kplékplé yé sɔ ɖó dò wɔ mɛ.', # MODIF
	'texte_acces_ldap_anonyme_1' => 'mi kɛnklɛ̂n bó ná lìnlìn mi tɔn ɖé wúɖò kplékplé yé sɔ ɖó dò wɔ mɛ',
	'texte_admin_effacer_01' => 'mi ná sɔ mɔ àlì gégéréinstallation de SPIP pour recréer une nouvelle base ainsi qu’un premier accès administrateur.',
	'texte_adresse_annuaire_1' => 'mi ná sɔ mɔ àlì gégé «localhost».)',
	'texte_ajout_auteur' => 'mi ná sɔ mɔ àlì gégé :',
	'texte_annuaire_ldap_1' => 'mi ná sɔ mɔ àlì gégé.',
	'texte_article_statut' => ':',
	'texte_article_virtuel' => 'wékpá é lɔ',
	'texte_article_virtuel_reference' => 'wékpá é lɔ.',
	'texte_aucun_resultat_auteur' => 'xógbè lɛ "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'nyɔwlántɔ lɛ .',
	'texte_auteurs' => 'nyɔwlántɔ lɛ ',
	'texte_choix_base_1' => 'mi sɔ xóxòkplégbàví mi tɔn :',
	'texte_choix_base_2' => 'mɔ SQL nɔ hɛnxóxòkplégbàví',
	'texte_choix_base_3' => 'mi cyían ɖê jɛ ɖéwú ɔ:',
	'texte_compte_element' => '@count@ kwín',
	'texte_compte_elements' => '@count@ kwín',
	'texte_connexion_mysql' => 'tòbítùntìto kléwúngbàví ɔ jɛ vɔwɛn é lɔ yé sɛ ɖó ɔ mi kɛnklɛ̂n bó ná lìnlìn mi tɔn ɖé wúSQL, kplékplé yé sɔ ɖó dò wɔ mɛ SQL.', # MODIF
	'texte_contenu_article' => '(Mi wlán wékpá sín xòmɛ ɖó xásádómɛ.)',
	'texte_contenu_articles' => 'gblogblojí é lɔ nɔ zɔn bɔ mi nɔ sɛ  wɛn ɖó bó nɔ lɛ yí wɛnxó kléwun lɛ wěmà kléwún ɖé lɛ wɛbɔ yé nɔ zɔn bɔ xó lɛ nɔ yí àtɛjí gànmɛgànmɛmi sɔ xóxòkplégbàví mi tɔn mɔ.',
	'texte_crash_base' => 'Nú xóxòkplégbàví gblè ɔ mi síwú lɛ vɔ blóɖó.',
	'texte_creer_rubrique' => 'Có mi ná wlán wěmà ɔ mi ɖó ná bló àkpáxwé ɖòkpó hwɛ.',
	'texte_date_creation_article' => 'Gbêgbè yé wlán wěmà ɔ :',
	'texte_date_publication_anterieure' => 'AZAN ƉÊ YE SƆ WĚMA SƆ XLƐ Ɔ :',
	'texte_date_publication_anterieure_nonaffichee' => 'Mi sɔ Azán ɖê yé sɔ wěmà sɔ xlɛ.',
	'texte_date_publication_article' => 'Mi sɔ Azán ɖê yé sɔ wěmà sɔ xlɛ :',
	'texte_descriptif_rapide' => 'mi tìnmɛ càcàcà',
	'texte_effacer_base' => 'mi sùnsùn xóxòkplé sùpípù tɔn ',
	'texte_en_cours_validation' => 'wékwín é lɔ ɖò wěmámɛyé mɔ wěmà ɖé ɖò gbè é lɔ mɛ áwékwín ɖê yé mà tùn à lɛ ɔ ɖò vɔvɔmɛ. Zìn yé bó kpɔn àyì é yè b ɖó yèwú ɔ.', # MODIF
	'texte_enrichir_mise_a_jour' => 'mi síwú zán kwín é lɔ lɛ».',
	'texte_fichier_authent' => 'xó kléwun lɛ wěmà kléwún ɖé lɛ wɛbɔ yé nɔ zɔn bɔ xó lɛ nɔ yí àtɛjí gànmɛgànmɛmi sɔ xóxòkplégbàví mi tɔn mɔnɔ hɛnmi cyían ɖê jɛ ɖéwú ɔ', # MODIF
	'texte_informations_personnelles_1' => 'Tìtòmɛ ɔ ná mi àcɛ mi ɖé sú tɔn mi .',
	'texte_informations_personnelles_2' => 'Nú mi lɛ ján bló bɔ àcɛ mi tɔn ɖò àzɔ wàwɛ tɛgbɛ ɔ mi síwú', # MODIF
	'texte_introductif_article' => '(Có nú mi ná bɛ xó ɔ.)',
	'texte_jeu_caractere' => 'vlàvò nú mi gòsínbò dózò nú ɖéxlɛtɔ mi tɔn  mi k pɔn àcɛ winwl tɔn E ɖò àkpáxwé ɔ mɛ Tìtòmɛ ɔ ná mi àcɛ mi ɖé sú tɔn mi Nú mi lɛ ján bló bɔ àcɛ mi tɔn ɖò àzɔ wàwɛ tɛgbɛ ɔ mi síwú(balise <tt>#CHARSET</tt>).',
	'texte_login_ldap_1' => 'vlàvò nú mi gòsínbò dózò nú ɖéxlɛtɔ mi tɔn  mi k pɔn àcɛ winwl tɔn E ɖò àkpáxwé ɔ mɛ Tìtòmɛ ɔ ná mi àcɛ mi ɖé sú tɔn mi Nú mi lɛ ján bló bɔ àcɛ mi tɔn ɖò àzɔ wàwɛ tɛgbɛ ɔ mi síwú',
	'texte_login_precaution' => 'vlàvò nú mi gòsínbò dózò nú ɖéxlɛtɔ mi tɔn  mi k pɔn àcɛ winwl tɔn E ɖò àkpáxwé ɔ mɛ Tìtòmɛ ɔ ná mi àcɛ mi ɖé sú tɔn mi Nú mi lɛ ján bló bɔ àcɛ mi tɔn ɖò àzɔ wàwɛ tɛgbɛ ɔ mi síwú...',
	'texte_mise_a_niveau_base_1' => 'wɛn wékpá tɔn yé sɔ xlɛàlɔwlí yɔyɔ lɛ ná jɛ àtɛ ɔ jími ná sɔ yé xlɛ àzɔn ɖókpó',
	'texte_modifier_article' => 'ɖyɔ wékpá ɔ:',
	'texte_multilinguisme' => 'vlàvò nú mi gòsínbò dózò nú ɖéxlɛtɔ mi tɔn  mi k pɔn àcɛ winwl tɔn E ɖò àkpáxwé ɔ mɛ Tìtòmɛ ɔ ná mi àcɛ mi ɖé sú tɔn mi Nú mi lɛ ján bló bɔ àcɛ mi tɔn ɖò àzɔ wàwɛ tɛgbɛ ɔ mi síwúCó nú mi ná bɛ xó ɔ nɛ nyí ɖɔ wɛn é lɔ kò yí àtɛ ɔ jí ɖá yí ɔ mi xlɛ nɔtɛn ', # MODIF
	'texte_multilinguisme_trad' => 'wɛn wékpá tɔn yé sɔ xlɛmi jláɖyɔ wékpá ɔmɔ̂ ɖò àzɔ wà wɛ á.', # MODIF
	'texte_non_compresse' => 'xókplé(mɔ mi tɔn sìwú yí wàlɔ é nɛ lɛ á)',
	'texte_nouvelle_version_spip_1' => 'wàlɔ sùpípù ɖévó wɛ mi sɔ.',
	'texte_nouvelle_version_spip_2' => 'Có nú mi ná bɛ xó ɔ nɛ nyí ɖɔ wɛn é lɔ kò yí àtɛ ɔ jí ɖá yí ɔ mi xlɛ nɔtɛn àlɔwlí yɔyɔ lɛ ná jɛ àtɛ ɔ jími ná sɔ yé xlɛ àzɔn ɖókpówɛn wékpá tɔn yé sɔ xlɛmi jláɖyɔ wékpá ɔmɔ̂ ɖò àzɔ wà wɛ áxókplémɔ mi tɔn sìwú yí wàlɔ é nɛ lɛ ámi hɛn mi ná zán wàlɔ càcàcà ɔ ámi ɖé sú mi bló jɛ xá myɔ  wékwín yɔyɔ...)', # MODIF
	'texte_operation_echec' => 'mi lɛ vɔ yí wékpá ɖé wá ɔ jí mi lɛ vɔ kpɔn xó é xwétɔ̂ sɛɖó ɔ.',
	'texte_plus_trois_car' => 'E zɛ kwín àtɔn  wú',
	'texte_plusieurs_articles' => 'yé mɔ nyɔwlántɔ gégé"@cherche_auteur@":',
	'texte_port_annuaire' => '(àcɛ yé nɔ ná nɔ jɛɖó.)',
	'texte_proposer_publication' => 'Nú mi wlán wěmà mi tɔn fó ɔ mi síwú sɔɖó àtɛ jí .',
	'texte_proxy' => 'Gbêgbè yé wlán wěmà ɔMi sɔ Azán ɖê yé sɔ wěmà sɔ xlɛàlɔwlí ɖévó lɛ ɖê gòsín gblogblojí é lɔ ján mi tìnmɛ càcàcàxójíjlá ɔmi sɔ ɖidé ɖó wěmà lɛ mɛsùpípù tɔn nú mi ná tò wěmà mi tɔn gànjí ɔ mi síwú zán kwín é lɔ lɛmi kó mɔ mi àmɔ mi sɔ ɖò xóxòkplégbàví ɔ mɛ ámi lɛ vɔ yí kànjí.',
	'texte_publication_articles_post_dates' => 'Wàlɔtɛ sùpípù kàsíwú bló wémà ɖê jló ná sɔɖó àtɛ jí hwè ɖé vó nú ɔ?',
	'texte_rappel_selection_champs' => '[Mi má wɔn bó sɔ kɛn nú tɛnmɛ ó.]',
	'texte_recalcul_page' => 'Mi wɔn wékpá ɖòkpó sín àkɔwúntà bló mi ɖè.Mi lɛ vɔ bó zín .',
	'texte_recuperer_base' => 'mi bló xóxòkplé ɔ ɖó',
	'texte_reference_mais_redirige' => 'wémà é lɔ sùpípù mɛ wɛ é mɔ àcɛ ɖé àmɔ nɔtɛn ɖévɔ mɛ wɛ é xwè',
	'texte_requetes_echouent' => 'Tìtòmɛ Sùpípù tɔn sɔ gbɔn uZine jíEtɛ wɛ nyí sùpípùWěmàxòkplé sùpípù tɔntɛmɛbìbá  - blòɖóTìtòmɛ é nɔ zɔn bɔ yè nɔ ɖè nɛ ɖò gblogblòjí E zɛ kwín àtɔn  wúàcɛ yé nɔ ná nɔ jɛɖóNú mi wlán wěmà mi tɔn fó ɔ mi síwú sɔɖó àtɛ jí Wàlɔtɛ sùpípù kàsíwú bló wémà ɖê jló ná sɔɖó àtɛ jí hwè ɖé vó nú ɔMi wɔn wékpá ɖòkpó sín àkɔwúntà bló mi ɖè.Mi lɛ vɔ bó zín bó sɔ kɛn nú tɛnmɛ ówékpá nɔ bló àkɔwúntà wémà é ɖò àkpéxwé lɛ̂ mɛ', # MODIF
	'texte_selection_langue_principale' => 'Sùpípù ɔ tìtómɛ nù jíjlá tɔn ɖê minirézo kéjé bó lɛ vlɔnkán nú bíbló gblògblòjí uZine tɔn ɔ. Mì sɔ kɛ mí ɖò àcɛ wàlɔ GPl tɔn mɛ. Mī zé bò zán bó dó bló gblògblòjí lɛ̂ ná : é síwú nyí mì tɔn ɖé sú kàbí gbɛtá ɖé tɔn, kàbí tòxóɖɔgbɛ ɖé tɔn, àló àjɔwíwá wú.Gblògblòjí é lɔ̂, é wɛ nyí  Wěmàxòkplé sùpípù tɔn ɖò tájí. Mí ná lɛ mɔ àlɔwlí gégé ɖê ná ɖɔn mî yì gblògblòjí ɖê jí kplékplé lɛ̂ nɔ tîn ɖè ɔ Tìtòmɛ Sùpípù tɔn sɔ gbɔn uZine jíEtɛ wɛ nyí sùpípùWěmàxòkplé sùpípù tɔn',
	'texte_sous_titre' => 'Xótá gúdó',
	'texte_statistiques_visites' => '(barres foncées : vòdùngbè / courbe foncée : évolution de la moyenne)',
	'texte_statut_attente_validation' => 'E kpó bɔ yé ná sɔ kɛn ná',
	'texte_statut_publies' => 'sɔɖò àtɛjí',
	'texte_statut_refuses' => 'gbɛ bí',
	'texte_suppression_fichiers' => 'tɛmɛbìbá  - blòɖóTìtòmɛ é nɔ zɔn bɔ yè nɔ ɖè nɛ ɖò gblogblòjí E zɛ kwín àtɔn  wúàcɛ yé nɔ ná nɔ jɛɖóNú mi wlán wěmà mi tɔn fó ɔ mi síwú sɔɖó àtɛ jí Wàlɔtɛ sùpípù kàsíwú bló wémà ɖê jló ná sɔɖó àtɛ jí hwè ɖé vó nú ɔMi wɔn wékpá ɖòkpó sín àkɔwúntà bló mi ɖè.Mi lɛ vɔ bó zín bó sɔ kɛn nú tɛnmɛ ó',
	'texte_sur_titre' => 'xótájí',
	'texte_table_ok' => 'wàlɔ̂ sɔ gbè.',
	'texte_tentative_recuperation' => 'tɛnkpɔn bíblóɖó tɔn',
	'texte_tenter_reparation' => 'tɛnkpɔn bíblóɖó tɔn',
	'texte_test_proxy' => 'tɛnkpɔn  proxy,E zɛ kwín àtɔn  wúàcɛ yé nɔ ná nɔ jɛɖóNú mi wlán wěmà mi tɔn fó ɔ mi síwú sɔɖó àtɛ jí  .',
	'texte_titre_02' => 'xótá :',
	'texte_titre_obligatoire' => 'xótá[dódó]',
	'texte_travail_article' => '@nom_auteur_modif@ é wàzɔ ɖó wékpá é lɔ wú @date_diff@ cɛjú',
	'texte_travail_collaboratif' => 'Sùpípù ɔ tìtómɛ nù jíjlá tɔn ɖê minirézo kéjé bó lɛ vlɔnkán nú bíbló gblògblòjí uZine tɔn ɔ. Mì sɔ kɛ mí ɖò àcɛ wàlɔ GPl tɔn mɛ. Mī zé bò zán bó dó bló gblògblòjí lɛ̂ ná : é síwú nyí mì tɔn ɖé sú kàbí gbɛtá ɖé tɔn, kàbí tòxóɖɔgbɛ ɖé tɔn, àló àjɔwíwá wú.Gblògblòjí é lɔ̂, é wɛ nyí  Wěmàxòkplé sùpípù tɔn ɖò tájí. Mí ná lɛ mɔ àlɔwlí gégé ɖê ná ɖɔn mî yì gblògblòjí ɖê jí kplékplé lɛ̂ nɔ tîn ɖè ɔ ',
	'texte_vide' => 'jɛ vɔ',
	'texte_vider_cache' => 'gbàv i ɔ jɛ vɔ',
	'titre_admin_tech' => 'wàlɔ zɔ',
	'titre_admin_vider' => 'wàlɔ zɔ',
	'titre_cadre_afficher_article' => 'xlɛ wékpá lɛ',
	'titre_cadre_afficher_traductions' => 'mi xlɛ ɖê gbè lɛ tìnmɛ gbɔn wɛ é :',
	'titre_cadre_ajouter_auteur' => 'mi gɔ nyɔwlántɔ ɖòkpó ná :',
	'titre_cadre_interieur_rubrique' => 'àkpáxwé ɔ mɛ',
	'titre_cadre_numero_auteur' => 'núméló nyɔwlántɔ tɔn',
	'titre_cadre_signature_obligatoire' => 'ɖálɔwěmàmɛ [dódó]',
	'titre_config_fonctions' => 'tò gblogblojí ɔ ',
	'titre_configuration' => 'tò gblogblojí ɔ ',
	'titre_connexion_ldap' => 'wàlɔ :càcàdó LDAP',
	'titre_groupe_mots' => 'Xóxòkplé lɛ :',
	'titre_langue_article' => 'Gbèzán wékpâ tɔn', # MODIF
	'titre_langue_rubrique' => 'Gbèzán àkpáxwé  ɔ tɔn', # MODIF
	'titre_langue_trad_article' => 'Gbèzán kpó tìnmɛ wékpâ tɔn ',
	'titre_les_articles' => 'Wékpa lɛ  ',
	'titre_naviguer_dans_le_site' => 'kéjénúmɛ ɖò gblogblo ɔ jí ...',
	'titre_nouvelle_rubrique' => 'àkpáxwé yɔyɔ',
	'titre_numero_rubrique' => 'númɛló àkpáxwé tɔn :',
	'titre_page_articles_edit' => 'ɖyɔ : @titre@',
	'titre_page_articles_page' => 'wékpá lɛ',
	'titre_page_articles_tous' => 'gblogblojí  ɔ  bí ',
	'titre_page_calendrier' => 'kàlanɖlyé@nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Tìtò gblogblojí  ɔ  tɔn',
	'titre_page_delete_all' => 'Sùnsùn bó gbìdí bí',
	'titre_page_recherche' => 'xógbè é tɔn ɖò nú bíbà ɔ mɛ ɔ @recherche@',
	'titre_page_statistiques_referers' => 'àkɔŋtá ',
	'titre_page_upgrade' => 'mi vɛ jɔwú nú sùpípù ɔ ',
	'titre_publication_articles_post_dates' => 'ɖéxlɛ wékpá é ná wà lɛ tɔn',
	'titre_reparation' => 'Bìblòɖó',
	'titre_suivi_petition' => 'Bɔ núkún ɖó xójíjlá lɛ jí',
	'trad_article_traduction' => 'wàlɔ wépká é lɔ tɔn lɛ bí',
	'trad_delier' => 'yé má cá wépká é lɔ ɖó tìnmɛ é lɔ wú ó', # MODIF
	'trad_lier' => 'kò nyí tìnmɛ wékpá ɖévó tɔn :',
	'trad_new' => 'Lɛ wlán tìnmɛ wékpá ɖévó tɔn' # MODIF
);

?>
